Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(135)

Unified Diff: content/browser/frame_host/navigation_entry_impl.h

Issue 2174293002: NonValidatingReload: Monitor reload operations in NavigationControllerImpl (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: cleanup Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/navigation_entry_impl.h
diff --git a/content/browser/frame_host/navigation_entry_impl.h b/content/browser/frame_host/navigation_entry_impl.h
index 4c96d55e2b7342d18cd35e31ca6ae2b681e20e3f..e2cf7a087479f2b0b3ea2e852982b2a02032c692 100644
--- a/content/browser/frame_host/navigation_entry_impl.h
+++ b/content/browser/frame_host/navigation_entry_impl.h
@@ -20,6 +20,7 @@
#include "content/public/browser/favicon_status.h"
#include "content/public/browser/global_request_id.h"
#include "content/public/browser/navigation_entry.h"
+#include "content/public/browser/reload_type.h"
#include "content/public/browser/restore_type.h"
#include "content/public/browser/ssl_status.h"
#include "content/public/common/page_state.h"
@@ -303,7 +304,7 @@ class CONTENT_EXPORT NavigationEntryImpl
}
// The RestoreType for this entry. This is set if the entry was retored. This
// is set to RESTORE_NONE once the entry is loaded.
void set_restore_type(RestoreType type) {
restore_type_ = type;
}
@@ -311,6 +312,11 @@ class CONTENT_EXPORT NavigationEntryImpl
return restore_type_;
}
+ void set_reload_type(ReloadType type) {
Charlie Reis 2016/09/19 22:23:52 Please document these.
Takashi Toyoshima 2016/09/26 12:23:34 Done.
+ reload_type_ = type;
+ }
+ ReloadType reload_type() const { return reload_type_; }
+
void set_transferred_global_request_id(
const GlobalRequestID& transferred_global_request_id) {
transferred_global_request_id_ = transferred_global_request_id;
@@ -505,6 +511,9 @@ class CONTENT_EXPORT NavigationEntryImpl
bool has_user_gesture_;
#endif
+ // Set when a reload is requested to check navigation type at commit time.
Charlie Reis 2016/09/19 22:23:52 Please mention that this is ReloadType::NONE for a
Takashi Toyoshima 2016/09/26 12:23:34 Done.
+ ReloadType reload_type_;
+
// Used to store extra data to support browser features. This member is not
// persisted, unless specific data is taken out/put back in at save/restore
// time (see TabNavigation for an example of this).
@@ -303,7 +304,7 @@ class CONTENT_EXPORT NavigationEntryImpl
}
// The RestoreType for this entry. This is set if the entry was retored. This
- // is set to RESTORE_NONE once the entry is loaded.
+ // is set to RestoreType::NONE once the entry is loaded.
void set_restore_type(RestoreType type) {
restore_type_ = type;

Powered by Google App Engine
This is Rietveld 408576698